@@ -57,9 +57,45 @@
 {% endmacro %}
 
 
+{% macro presto__create_csv_table(model, agate_table) %}
+  {%- set column_override = model['config'].get('column_types', {}) -%}
+  {%- set quote_seed_column = model['config'].get('quote_columns', None) -%}
+  {%- set _properties = config.get('properties') -%}
+
+  {% set sql %}
+    create table {{ this.render() }} (
+        {%- for col_name in agate_table.column_names -%}
+            {%- set inferred_type = adapter.convert_type(agate_table, loop.index0) -%}
+            {%- set type = column_override.get(col_name, inferred_type) -%}
+            {%- set column_name = (col_name | string) -%}
+            {{ adapter.quote_seed_column(column_name, quote_seed_column) }} {{ type }} {%- if not loop.last -%}, {%- endif -%}
+        {%- endfor -%}
+    ) {{ properties(_properties) }}
+  {% endset %}
+
+  {% call statement('_') -%}
+    {{ sql }}
+  {%- endcall %}
+
+  {{ return(sql) }}
+{% endmacro %}
+
+{% macro properties(properties) %}
+  {%- if properties is not none -%}
+      WITH (
+          {%- for key, value in properties.items() -%}
+            {{ key }} = {{ value }}
+            {%- if not loop.last -%}{{ ',\n  ' }}{%- endif -%}
+          {%- endfor -%}
+      )
+  {%- endif -%}
+{%- endmacro -%}
+
+
 {% macro presto__create_table_as(temporary, relation, sql) -%}
-  create table
-    {{ relation }}
+  {%- set _properties = config.get('properties') -%}
+  create table {{ relation }}
+    {{ properties(_properties) }}
   as (
     {{ sql }}
   );
@@ -115,8 +151,8 @@
 {% endmacro %}
 
 
-{% macro presto__load_csv_rows(model, agate_table) %}
-  {{ return(basic_load_csv_rows(model, 1000, agate_table)) }}
+{% macro presto__get_batch_size() %}
+  {{ return(1000) }}
 {% endmacro %}
 
 
